pub(crate) struct Flag {
failed: Atomic<bool>,
}🔬This is a nightly-only experimental API. (
sync_poison_mod #134646)Fields
failed: Atomic<bool>🔬This is a nightly-only experimental API. (
sync_poison_mod #134646)Available on
panic=unwind only.Implementations
Sourceimpl Flag
impl Flag
pub const fn new() -> Flag
🔬This is a nightly-only experimental API. (
sync_poison_mod #134646)Sourcepub fn borrow(&self) -> LockResult<()>
🔬This is a nightly-only experimental API. (sync_poison_mod #134646)
pub fn borrow(&self) -> LockResult<()>
sync_poison_mod #134646)Checks the flag for an unguarded borrow, where we only care about existing poison.
Sourcepub fn guard(&self) -> LockResult<Guard>
🔬This is a nightly-only experimental API. (sync_poison_mod #134646)
pub fn guard(&self) -> LockResult<Guard>
sync_poison_mod #134646)Checks the flag for a guarded borrow, where we may also set poison when done.
pub fn done(&self, guard: &Guard)
🔬This is a nightly-only experimental API. (
sync_poison_mod #134646)Available on
panic=unwind only.pub fn get(&self) -> bool
🔬This is a nightly-only experimental API. (
sync_poison_mod #134646)Available on
panic=unwind only.pub fn clear(&self)
🔬This is a nightly-only experimental API. (
sync_poison_mod #134646)Auto Trait Implementations
impl !Freeze for Flag
impl RefUnwindSafe for Flag
impl Send for Flag
impl Sync for Flag
impl Unpin for Flag
impl UnsafeUnpin for Flag
impl UnwindSafe for Flag